package com.yizhi.enroll.application.feign;

import com.baomidou.mybatisplus.plugins.Page;
import com.yizhi.enroll.application.vo.domain.Enroll;
import com.yizhi.enroll.application.vo.domain.EnrollRecord;
import com.yizhi.enroll.application.vo.*;
import com.yizhi.util.application.domain.BizResponse;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@FeignClient(name = "enroll", contextId = "EnrollFeignClient")
public interface EnrollFeignClient {

	@RequestMapping(value="/remote/manage/enroll/insertEnroll", method=RequestMethod.POST)
	Long insertEnroll(@RequestBody Enroll enroll);

	/**
	 * 新增项目 版本2
	 * 相对insertEnroll()方法；新增参数校验；2.修改返回值
	 */
	@PostMapping("/remote/manage/enroll/insertEnroll/v2")
	BizResponse<String> insertEnrollV2(@RequestBody Enroll enroll);

	@RequestMapping(value="/remote/manage/enroll/updateEnroll", method=RequestMethod.POST)
	Long updateEnroll(@RequestBody Enroll enroll);

	@RequestMapping(value="/remote/manage/enroll/view/{id}", method=RequestMethod.GET)
	Enroll selectByProjectId(@PathVariable("id") Long id);

	@RequestMapping(value="/remote/manage/enroll/auditEnroll", method=RequestMethod.POST)
	boolean auditEnroll(@RequestBody AuditVO vo);

	@RequestMapping(value="/remote/api/enroll/student/insertTrEnrollRecord/{id}", method=RequestMethod.POST)
	Long insertTrEnrollRecord(@PathVariable("id") Long id);

	@RequestMapping(value="/remote/api/enroll/selectTrainningEnroll", method=RequestMethod.POST)
	List<TrainningEnrollVO> selectTrainningEnroll(@RequestBody List<Long> idList);

	@PostMapping("/remote/manage/enroll/selectEnrollByProjectId")
	ReturnEnrollVO selectEnrollByProjectId(@RequestBody ProjectAccountVO vo);

	@GetMapping("/remote/manage/enroll/listEnroll")
	Page<EnrollerVo> listEnroll(@RequestBody EnrollerParam enrollerParam);
	
	@PostMapping("/remote/manage/enroll/state/update")
    Integer updateState(@RequestBody EnrollRecord enrollRecord);

	@GetMapping("/remote/api/enroll/getEnroll")
	GetEnrollVO getEnrollByProjectId(@RequestParam("projectId") Long projectId, @RequestParam("accountId") Long accountId);

	@GetMapping("/remote/api/enroll/pc/getEnroll")
	public GetEnrollVO pcGetEnrollByProjectId(@RequestParam("projectId") Long projectId, @RequestParam("accountId") Long accountId);

	/**
	 * 根据项目id删除报名
	 * @return 1 成功；-1失败
	 */
	@PostMapping("/remote/manage/enroll/delete")
	Integer deleteEnrollByProjectId(@RequestBody ProjectAccountVO vo);
	
}
